@@ -28,6 +28,12 @@ def parse_args() -> argparse.Namespace:
         required=False,
         help="The league model to use.",
     )
+    parser.add_argument(
+        "--timeout",
+        required=False,
+        help="The timeout to use (in seconds).",
+        type=int,
+    )
     parser.add_argument(
         "file",
         default=STDOUT_FILE,
