@@ -7,16 +7,20 @@ import os
 from urllib.parse import urlparse
 
 import pytest_is_running
-import requests_cache
 from bs4 import BeautifulSoup
 from dateutil.parser import parse
 from dateutil.relativedelta import relativedelta
+from scrapesession.scrapesession import ScrapeSession  # type: ignore
 
 from ....cache import MEMORY
 from ...player_model import VERSION, PlayerModel
 from ...sex import Sex
 from ...species import Species
 
+_NON_WAYBACK_URLS = {
+    "https://afltables.com/afl/stats/players/J/Junior_Rioli.html",
+}
+
 
 def _create_afl_afltables_player_model(
     player_url: str,
@@ -45,7 +49,7 @@ def _create_afl_afltables_player_model(
     bounces: int | None,
     goal_assists: int | None,
     percentage_played: float | None,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime,
     version: str,
 ) -> PlayerModel:
@@ -53,7 +57,11 @@ def _create_afl_afltables_player_model(
     last_component = o.path.split("/")[-1]
     identifier, _ = os.path.splitext(last_component)
     jersey = "".join(filter(str.isdigit, jersey))
-    response = session.get(player_url)
+    if player_url in _NON_WAYBACK_URLS:
+        with session.wayback_disabled():
+            response = session.get(player_url)
+    else:
+        response = session.get(player_url)
     response.raise_for_status()
 
     soup = BeautifulSoup(response.text, "lxml")
@@ -990,7 +998,7 @@ def _cached_create_afl_afltables_player_model(
     bounces: int | None,
     goal_assists: int | None,
     percentage_played: float | None,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime,
     version: str,
 ) -> PlayerModel:
@@ -1031,7 +1039,7 @@ def create_afl_afltables_player_model(
     player_url: str,
     jersey: str,
     kicks: int | None,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     name: str,
     marks: int | None,
     handballs: int | None,
